@@ -10,6 +10,7 @@ pkglist_to_deps() {
         -e 's,^\(systemd-sysv\|sysvinit-core\),systemd-sysv | sysvinit-core,' \
         -e 's,^\(libsystemd-[a-z1-9-]*0\),libsystemd0 | \1,' \
         -e 's,^\(util-linux\|fdisk\),fdisk | util-linux (<< 2.29.2),' \
+        -e 's,^\(dhcpcd-base\|isc-dhcp-client\),dhcpcd-base | isc-dhcp-client,' \
         -e '/^\(bash\|coreutils\|findutils\|grep\|gzip\|libc-bin\|sed\|tar\)$/d' \
         | tr '\n' ','
     echo
@@ -22,6 +23,6 @@ do
         >> debian/libguestfs-$p.substvars
 done
 
-cat debian/libguestfs0/usr/lib/*-*/guestfs/supermin.d/packages \
+cat debian/libguestfs0t64/usr/lib/*-*/guestfs/supermin.d/packages \
     |  pkglist_to_deps \
-    >> debian/libguestfs0.substvars
+    >> debian/libguestfs0t64.substvars
